#!/bin/bash
ip_num=`grep address /etc/network/interfaces | awk '{print $2}' | grep -c '.'`
ipv6_if=`grep -m 1 'up ip addr add' /etc/network/interfaces | awk '{print $5}'`
ipv6_avail=`grep 'up ip addr add' /etc/network/interfaces | awk '{print $5}'`
  cat << EOF > /etc/netplan/01-netcfg.yaml
# This file describes the network interfaces available on your system
# # For more information, see netplan(5).
network:
  version: 2
  renderer: networkd
  ethernets:
    ens3:
      dhcp4: false
EOF
  if [ -n $ipv6_if ]; then
    cat << EOF >> /etc/netplan/01-netcfg.yaml
      dhcp6: false
      accept-ra: false
EOF
  fi
  cat << EOF >> /etc/netplan/01-netcfg.yaml
      addresses:
EOF
    i=1
    j=1
    ip_avail=`grep address /etc/network/interfaces | awk '{print $2}'`
    gateway_all=`grep gateway /etc/network/interfaces | awk '{print $2}'`
    for ip in ${ip_avail[@]}
    do
        netmask=`grep netmask /etc/network/interfaces | awk '{print $2}' | awk "NR==$i"`
        mask2cdr ()
        {
            # Assumes there's no "255." after a non-255 byte in the mask
            local x=${1##*255.}
            set -- 0^^^128^192^224^240^248^252^254^ $(( (${#1} - ${#x})*2 )) ${x%%.*}
            x=${1%%$3*}
            cidr=$(( $2 + (${#x}/4) ))
        }
        mask2cdr $netmask
        cat << EOF >> /etc/netplan/01-netcfg.yaml
        - $ip/$cidr
EOF
        let i++
    done
    if [ -n $ipv6_if ]; then
      gateway6=`grep 'up ip -6 route add default via' /etc/network/interfaces | awk '{print $8}'`
      b=1
      for ipv6 in ${ipv6_avail[@]}
      do
        cat << EOF >> /etc/netplan/01-netcfg.yaml
        - ${ipv6}
EOF
        let b++
      done
    fi
        cat << EOF >> /etc/netplan/01-netcfg.yaml
      routes:
EOF
    for gateway in ${gateway_all[@]}
    do
        gateway=`grep gateway /etc/network/interfaces | awk '{print $2}' | awk "NR==$j"`
        cat << EOF >> /etc/netplan/01-netcfg.yaml
        - to: default
          via: $gateway
          metric: $j
EOF
        let j++
    done
        c=1
    while((c <= b-1))
    do
        cat << EOF >> /etc/netplan/01-netcfg.yaml
        - to: default
          via: $gateway6
          metric: $c
EOF
        ((c++))
    done
    dns1=`grep dns-nameservers /etc/network/interfaces | awk '{print $2}' | awk "NR==1"`
    dns2=`grep dns-nameservers /etc/network/interfaces | awk '{print $3}' | awk "NR==1"`
    if [ -z $ipv6_if ]; then
    cat << EOF >> /etc/netplan/01-netcfg.yaml
      nameservers:
        addresses: ["${dns1}", "${dns2}"]
EOF
    else
      dns6_1=`grep ':' /etc/resolv.conf | awk '{print $2}' |  awk "NR==1"`
      dns6_2=`grep ':' /etc/resolv.conf | awk '{print $2}' |  awk "NR==2"`
      cat << EOF >> /etc/netplan/01-netcfg.yaml
      nameservers:
        addresses: ["${dns1}", "${dns2}", "${dns6_1}", "${dns6_2}"]
EOF
    fi
chmod 600 /etc/netplan/01-netcfg.yaml
netplan apply
exit 0
